@@ -42,26 +42,26 @@ void LmdbTxnGet(LmdbCtx ctx, enum LmdbOpenMode mode)
     // Read transactions are reused, if possible
     if (ctx->txn && mode == LmdbRead)
     {
-        ctx->err = mdb_txn_renew(ctx->txn);
-        if (ctx->err)
-        {
-            ctx->txn = NULL;
-        }
+	ctx->err = mdb_txn_renew(ctx->txn);
+	if (ctx->err)
+	{
+	    ctx->txn = NULL;
+	}
     }
     else if (ctx->txn && mode == LmdbWrite)
     {
-        LmdbTxnAbort(ctx);
+	LmdbTxnAbort(ctx);
     }
 
     if (ctx->txn == NULL)
     {
-        ctx->err = mdb_txn_begin(ctx->env, NULL, 0, &ctx->txn);
+	ctx->err = mdb_txn_begin(ctx->env, NULL, 0, &ctx->txn);
     }
 
     if (ctx->err)
     {
-        ctx->txn = NULL;
-        return;
+	ctx->txn = NULL;
+	return;
     }
 
     // Given the setup above, and the arguments given, this won't fail.
@@ -150,7 +150,7 @@ Sv_RegisterLmdbStore(void)
  *
  *-----------------------------------------------------------------------------
  */
-static ClientData
+static void *
 ps_lmdb_open(
     const char *path)
 {
@@ -159,10 +159,10 @@ ps_lmdb_open(
     char *ext;
     Tcl_DString toext;
 
-    ctx = (LmdbCtx)ckalloc(sizeof(*ctx));
+    ctx = (LmdbCtx)Tcl_Alloc(sizeof(*ctx));
     if (ctx == NULL)
     {
-        return NULL;
+	return NULL;
     }
 
     ctx->env = NULL;
@@ -173,8 +173,8 @@ ps_lmdb_open(
     ctx->err = mdb_env_create(&ctx->env);
     if (ctx->err)
     {
-        ckfree(ctx);
-        return NULL;
+	Tcl_Free(ctx);
+	return NULL;
     }
 
     Tcl_DStringInit(&toext);
@@ -182,10 +182,9 @@ ps_lmdb_open(
     ctx->err = mdb_env_open(ctx->env, ext, MDB_NOSUBDIR|MDB_NOLOCK, 0666);
     Tcl_DStringFree(&toext);
 
-    if (ctx->err)
-    {
-        ckfree(ctx);
-        return NULL;
+    if (ctx->err) {
+	Tcl_Free(ctx);
+	return NULL;
     }
 
     return ctx;
@@ -208,20 +207,20 @@ ps_lmdb_open(
  */
 static int
 ps_lmdb_close(
-    ClientData handle)
+    void *handle)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     if (ctx->cur)
     {
-        mdb_cursor_close(ctx->cur);
+	mdb_cursor_close(ctx->cur);
     }
     if (ctx->txn)
     {
-        LmdbTxnAbort(ctx);
+	LmdbTxnAbort(ctx);
     }
 
     mdb_env_close(ctx->env);
-    ckfree(ctx);
+    Tcl_Free(ctx);
 
     return 0;
 }
@@ -244,10 +243,10 @@ ps_lmdb_close(
  */
 static int
 ps_lmdb_get(
-     ClientData  handle,
+     void *handle,
      const char *keyptr,
      char  **dataptrptr,
-     size_t     *lenptr)
+     Tcl_Size *lenptr)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     MDB_val key, data;
@@ -255,7 +254,7 @@ ps_lmdb_get(
     LmdbTxnGet(ctx, LmdbRead);
     if (ctx->err)
     {
-        return 1;
+	return 1;
     }
 
     key.mv_data = (void *)keyptr;
@@ -264,8 +263,8 @@ ps_lmdb_get(
     ctx->err = mdb_get(ctx->txn, ctx->dbi, &key, &data);
     if (ctx->err)
     {
-        mdb_txn_reset(ctx->txn);
-        return 1;
+	mdb_txn_reset(ctx->txn);
+	return 1;
     }
 
     *dataptrptr = (char *)data.mv_data;
@@ -299,10 +298,10 @@ ps_lmdb_get(
  */
 static int
 ps_lmdb_first(
-    ClientData  handle,
+    void *handle,
     char   **keyptrptr,
     char  **dataptrptr,
-    size_t     *lenptr)
+    Tcl_Size *lenptr)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     MDB_val key, data;
@@ -310,22 +309,22 @@ ps_lmdb_first(
     LmdbTxnGet(ctx, LmdbRead);
     if (ctx->err)
     {
-        return 1;
+	return 1;
     }
 
     ctx->err = mdb_cursor_open(ctx->txn, ctx->dbi, &ctx->cur);
     if (ctx->err)
     {
-        return 1;
+	return 1;
     }
 
     ctx->err = mdb_cursor_get(ctx->cur, &key, &data, MDB_FIRST);
     if (ctx->err)
     {
-        mdb_txn_reset(ctx->txn);
-        mdb_cursor_close(ctx->cur);
-        ctx->cur = NULL;
-        return 1;
+	mdb_txn_reset(ctx->txn);
+	mdb_cursor_close(ctx->cur);
+	ctx->cur = NULL;
+	return 1;
     }
 
     *dataptrptr = (char *)data.mv_data;
@@ -352,10 +351,10 @@ ps_lmdb_first(
  *-----------------------------------------------------------------------------
  */
 static int ps_lmdb_next(
-    ClientData  handle,
+    void *handle,
     char   **keyptrptr,
     char  **dataptrptr,
-    size_t     *lenptr)
+    Tcl_Size *lenptr)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     MDB_val key, data;
@@ -363,10 +362,10 @@ static int ps_lmdb_next(
     ctx->err = mdb_cursor_get(ctx->cur, &key, &data, MDB_NEXT);
     if (ctx->err)
     {
-        mdb_txn_reset(ctx->txn);
-        mdb_cursor_close(ctx->cur);
-        ctx->cur = NULL;
-        return 1;
+	mdb_txn_reset(ctx->txn);
+	mdb_cursor_close(ctx->cur);
+	ctx->cur = NULL;
+	return 1;
     }
 
     *dataptrptr = (char *)data.mv_data;
@@ -395,10 +394,10 @@ static int ps_lmdb_next(
  */
 static int
 ps_lmdb_put(
-    ClientData  handle,
+    void *handle,
     const char *keyptr,
     char      *dataptr,
-    size_t         len)
+    Tcl_Size len)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     MDB_val key, data;
@@ -406,7 +405,7 @@ ps_lmdb_put(
     LmdbTxnGet(ctx, LmdbWrite);
     if (ctx->err)
     {
-        return -1;
+	return -1;
     }
 
     key.mv_data = (void*)keyptr;
@@ -418,11 +417,11 @@ ps_lmdb_put(
     ctx->err = mdb_put(ctx->txn, ctx->dbi, &key, &data, 0);
     if (ctx->err)
     {
-        LmdbTxnAbort(ctx);
+	LmdbTxnAbort(ctx);
     }
     else
     {
-        LmdbTxnCommit(ctx);
+	LmdbTxnCommit(ctx);
     }
 
     return ctx->err ? -1 : 0;
@@ -447,7 +446,7 @@ ps_lmdb_put(
  */
 static int
 ps_lmdb_delete(
-    ClientData  handle,
+    void *handle,
     const char *keyptr)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
@@ -456,7 +455,7 @@ ps_lmdb_delete(
     LmdbTxnGet(ctx, LmdbWrite);
     if (ctx->err)
     {
-        return -1;
+	return -1;
     }
 
     key.mv_data = (void*)keyptr;
@@ -465,11 +464,11 @@ ps_lmdb_delete(
     ctx->err = mdb_del(ctx->txn, ctx->dbi, &key, NULL);
     if (ctx->err)
     {
-        LmdbTxnAbort(ctx);
+	LmdbTxnAbort(ctx);
     }
     else
     {
-        LmdbTxnCommit(ctx);
+	LmdbTxnCommit(ctx);
     }
 
     ctx->txn = NULL;
@@ -497,15 +496,14 @@ ps_lmdb_delete(
  */
 static void
 ps_lmdb_free(
-    ClientData handle,
-    void        *data)
+    void *handle,
+    TCL_UNUSED(void *))
 {
     LmdbCtx ctx = (LmdbCtx)handle;
-    (void)data;
 
     if (ctx->cur == NULL)
     {
-        mdb_txn_reset(ctx->txn);
+	mdb_txn_reset(ctx->txn);
     }
 }
 
@@ -527,7 +525,7 @@ ps_lmdb_free(
  */
 static const char*
 ps_lmdb_geterr(
-    ClientData handle)
+    void *handle)
 {
     LmdbCtx ctx = (LmdbCtx)handle;
     return mdb_strerror(ctx->err);
