@@ -18,6 +18,7 @@
 #include "tclThread.h"
 #include <stdlib.h> /* For strtoul */
 #include <string.h> /* For memset and friends */
+#include <stdarg.h> /* For va_list */
 
 /*
  * MSVC 8.0 started to mark many standard C library functions depreciated
@@ -47,6 +48,10 @@
 #   endif
 #endif
 
+#if defined(_WIN32) && defined(_MSC_VER) && _MSC_VER < 1900
+#  define snprintf _snprintf
+#endif
+
 /*
  * For linking against NaviServer/AOLserver require V4 at least
  */
@@ -58,6 +63,28 @@
 # endif
 #endif
 
+#if (TCL_MAJOR_VERSION == 8) && defined(USE_TCL_STUBS)
+#undef Tcl_Free
+#define Tcl_Free(p) tclStubsPtr->tcl_Free((void *)(p))
+#undef Tcl_Realloc
+#define Tcl_Realloc(p,m) tclStubsPtr->tcl_Realloc((void *)(p),(m))
+#endif
+
+#ifndef JOIN
+#  define JOIN(a,b) JOIN1(a,b)
+#  define JOIN1(a,b) a##b
+#endif
+
+#ifndef TCL_UNUSED
+#   if defined(__cplusplus)
+#	define TCL_UNUSED(T) T
+#   elif defined(__GNUC__) && (__GNUC__ > 2)
+#	define TCL_UNUSED(T) T JOIN(dummy, __LINE__) __attribute__((unused))
+#   else
+#	define TCL_UNUSED(T) T JOIN(dummy, __LINE__)
+#   endif
+#endif
+
 /*
  * Allow for some command names customization.
  * Only thread:: and tpool:: are handled here.
@@ -93,31 +120,23 @@ MODULE_SCOPE const char *TpoolInit(Tcl_Interp *interp);
 #define SpliceIn(a,b)                          \
     (a)->nextPtr = (b);                        \
     if ((b) != NULL)                           \
-        (b)->prevPtr = (a);                    \
+	(b)->prevPtr = (a);                    \
     (a)->prevPtr = NULL, (b) = (a)
 
 #define SpliceOut(a,b)                         \
     if ((a)->prevPtr != NULL)                  \
-        (a)->prevPtr->nextPtr = (a)->nextPtr;  \
+	(a)->prevPtr->nextPtr = (a)->nextPtr;  \
     else                                       \
-        (b) = (a)->nextPtr;                    \
+	(b) = (a)->nextPtr;                    \
     if ((a)->nextPtr != NULL)                  \
-        (a)->nextPtr->prevPtr = (a)->prevPtr
-
-/*
- * Version macros
- */
-
-#define TCL_MINIMUM_VERSION(major,minor) \
-  ((TCL_MAJOR_VERSION > (major)) || \
-    ((TCL_MAJOR_VERSION == (major)) && (TCL_MINOR_VERSION >= (minor))))
+	(a)->nextPtr->prevPtr = (a)->prevPtr
 
 /*
  * Utility macros
  */
 
 #define TCL_CMD(a,b,c) \
-  if (Tcl_CreateObjCommand((a),(b),(c),NULL, NULL) == NULL) \
+  if (Tcl_CreateObjCommand2((a),(b),(c),NULL, NULL) == NULL) \
     return NULL;
 
 #define OPT_CMP(a,b) \
@@ -138,58 +157,4 @@ typedef struct {
     char *server;
 } NsThreadInterpData;
 
-/*
- * Handle binary compatibility regarding
- * Tcl_GetErrorLine in 8.x
- * See Tcl bug #3562640.
- */
-
-MODULE_SCOPE int threadTclVersion;
-
-typedef struct {
-    void *unused1;
-    void *unused2;
-    int errorLine;
-} tclInterpType;
-
-#if defined(TCL_TIP285) && defined(USE_TCL_STUBS)
-# undef Tcl_GetErrorLine
-# define Tcl_GetErrorLine(interp) ((threadTclVersion>85)? \
-    ((int (*)(Tcl_Interp *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[605]))(interp): \
-    (((tclInterpType *)(interp))->errorLine))
-/* TIP #270 */
-# undef Tcl_AddErrorInfo
-# define Tcl_AddErrorInfo(interp, msg) ((threadTclVersion>85)? \
-    ((void (*)(Tcl_Interp *, Tcl_Obj *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[574]))(interp, Tcl_NewStringObj(msg, -1)): \
-    ((void (*)(Tcl_Interp *, const char *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[66]))(interp, msg))
-/* TIP #337 */
-# undef Tcl_BackgroundException
-# define Tcl_BackgroundException(interp, result) ((threadTclVersion>85)? \
-    ((void (*)(Tcl_Interp *, int))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[609]))(interp, result): \
-    ((void (*)(Tcl_Interp *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[76]))(interp))
-#elif !TCL_MINIMUM_VERSION(8,6)
-  /* 8.5, 8.4, or less - Emulate access to the error-line information */
-# define Tcl_GetErrorLine(interp) (((tclInterpType *)(interp))->errorLine)
-#endif
-
-/* When running on Tcl >= 8.7, make sure that Thread still runs when Tcl is compiled
- * with -DTCL_NO_DEPRECATED=1. Stub entries for Tcl_SetIntObj/Tcl_NewIntObj are NULL then.
- * Just use Tcl_SetWideIntObj/Tcl_NewWideIntObj in stead. We don't simply want to use
- * Tcl_SetWideIntObj/Tcl_NewWideIntObj always, since extensions might not expect to
- * get an actual "wideInt".
- */
-#if defined(USE_TCL_STUBS)
-# undef Tcl_SetIntObj
-# define Tcl_SetIntObj(objPtr, value) ((threadTclVersion>86)? \
-  ((void (*)(Tcl_Obj *, Tcl_WideInt))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[489]))(objPtr, (int)(value)): \
-  ((void (*)(Tcl_Obj *, int))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[61]))(objPtr, value))
-# undef Tcl_NewIntObj
-# define Tcl_NewIntObj(value) ((threadTclVersion>86)? \
-  ((Tcl_Obj * (*)(Tcl_WideInt))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[488]))((int)(value)): \
-  ((Tcl_Obj * (*)(int))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[52]))(value))
-# undef Tcl_GetUnicodeFromObj
-# define Tcl_GetUnicodeFromObj ((((&(tclStubsPtr->tcl_PkgProvideEx))[378]) != ((&(tclStubsPtr->tcl_PkgProvideEx))[434])) ? \
-  ((void (*)(Tcl_Obj *, int *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[434])) : ((void (*)(Tcl_Obj *, int *)) NULL))
-#endif
-
 #endif /* _TCL_THREAD_INT_H_ */
