@@ -33,10 +33,10 @@ typedef struct ThreadPool {
     int suspend;                    /* Set to 1 to suspend pool processing */
     char *initScript;               /* Script to initialize worker thread */
     char *exitScript;               /* Script to cleanup the worker */
-    int minWorkers;                 /* Minimum number or worker threads */
-    int maxWorkers;                 /* Maximum number of worker threads */
-    int numWorkers;                 /* Current number of worker threads */
-    int idleWorkers;                /* Number of idle workers */
+    Tcl_WideInt minWorkers;         /* Minimum number or worker threads */
+    Tcl_WideInt maxWorkers;         /* Maximum number of worker threads */
+    Tcl_WideInt numWorkers;         /* Current number of worker threads */
+    Tcl_WideInt idleWorkers;        /* Number of idle workers */
     size_t refCount;                /* Reference counter for reserve/release */
     Tcl_Mutex mutex;                /* Pool mutex */
     Tcl_Condition cond;             /* Pool condition variable */
@@ -102,16 +102,16 @@ static char *threadEmptyResult = (char *)"";
  * Functions implementing Tcl commands
  */
 
-static Tcl_ObjCmdProc TpoolCreateObjCmd;
-static Tcl_ObjCmdProc TpoolPostObjCmd;
-static Tcl_ObjCmdProc TpoolWaitObjCmd;
-static Tcl_ObjCmdProc TpoolCancelObjCmd;
-static Tcl_ObjCmdProc TpoolGetObjCmd;
-static Tcl_ObjCmdProc TpoolReserveObjCmd;
-static Tcl_ObjCmdProc TpoolReleaseObjCmd;
-static Tcl_ObjCmdProc TpoolSuspendObjCmd;
-static Tcl_ObjCmdProc TpoolResumeObjCmd;
-static Tcl_ObjCmdProc TpoolNamesObjCmd;
+static Tcl_ObjCmdProc2 TpoolCreateObjCmd;
+static Tcl_ObjCmdProc2 TpoolPostObjCmd;
+static Tcl_ObjCmdProc2 TpoolWaitObjCmd;
+static Tcl_ObjCmdProc2 TpoolCancelObjCmd;
+static Tcl_ObjCmdProc2 TpoolGetObjCmd;
+static Tcl_ObjCmdProc2 TpoolReserveObjCmd;
+static Tcl_ObjCmdProc2 TpoolReleaseObjCmd;
+static Tcl_ObjCmdProc2 TpoolSuspendObjCmd;
+static Tcl_ObjCmdProc2 TpoolResumeObjCmd;
+static Tcl_ObjCmdProc2 TpoolNamesObjCmd;
 
 /*
  * Miscelaneous functions used within this file
@@ -121,7 +121,7 @@ static int
 CreateWorker(Tcl_Interp *interp, ThreadPool *tpoolPtr);
 
 static Tcl_ThreadCreateType
-TpoolWorker(ClientData clientData);
+TpoolWorker(void *clientData);
 
 static int
 RunStopEvent(Tcl_Event *evPtr, int mask);
@@ -154,12 +154,12 @@ static ThreadPool*
 GetTpoolUnl(const char *tpoolName);
 
 static void
-ThrExitHandler(ClientData clientData);
+ThrExitHandler(void *clientData);
 
 static void
-AppExitHandler(ClientData clientData);
+AppExitHandler(void *clientData);
 
-static int
+static size_t
 TpoolReserve(ThreadPool *tpoolPtr);
 
 static size_t
@@ -194,15 +194,16 @@ InitWaiter(void);
 
 static int
 TpoolCreateObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
-    int ii, minw, maxw, idle;
+    Tcl_WideInt ii;
+    Tcl_WideInt minw, maxw;
+    int idle;
     char buf[64], *exs = NULL, *cmd = NULL;
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     /*
      * Syntax:  tpool::create ?-minworkers count?
@@ -227,11 +228,11 @@ TpoolCreateObjCmd(
     for (ii = 1; ii < objc; ii += 2) {
 	char *opt = Tcl_GetString(objv[ii]);
 	if (OPT_CMP(opt, "-minworkers")) {
-	    if (Tcl_GetIntFromObj(interp, objv[ii+1], &minw) != TCL_OK) {
+	    if (Tcl_GetWideIntFromObj(interp, objv[ii+1], &minw) != TCL_OK) {
 		return TCL_ERROR;
 	    }
 	} else if (OPT_CMP(opt, "-maxworkers")) {
-	    if (Tcl_GetIntFromObj(interp, objv[ii+1], &maxw) != TCL_OK) {
+	    if (Tcl_GetWideIntFromObj(interp, objv[ii+1], &maxw) != TCL_OK) {
 		return TCL_ERROR;
 	    }
 	} else if (OPT_CMP(opt, "-idletime")) {
@@ -240,10 +241,10 @@ TpoolCreateObjCmd(
 	    }
 	} else if (OPT_CMP(opt, "-initcmd")) {
 	    const char *val = Tcl_GetString(objv[ii+1]);
-	    cmd  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
+	    cmd  = strcpy((char *)Tcl_Alloc(objv[ii+1]->length+1), val);
 	} else if (OPT_CMP(opt, "-exitcmd")) {
 	    const char *val = Tcl_GetString(objv[ii+1]);
-	    exs  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
+	    exs  = strcpy((char *)Tcl_Alloc(objv[ii+1]->length+1), val);
 	} else {
 	    goto usage;
 	}
@@ -267,7 +268,7 @@ TpoolCreateObjCmd(
      * Allocate and initialize thread pool structure
      */
 
-    tpoolPtr = (ThreadPool*)ckalloc(sizeof(ThreadPool));
+    tpoolPtr = (ThreadPool *)Tcl_Alloc(sizeof(ThreadPool));
     memset(tpoolPtr, 0, sizeof(ThreadPool));
 
     tpoolPtr->minWorkers  = minw;
@@ -300,7 +301,7 @@ TpoolCreateObjCmd(
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
     snprintf(buf, sizeof(buf), "%s%p", TPOOL_HNDLPREFIX, tpoolPtr);
-    Tcl_SetObjResult(interp, Tcl_NewStringObj(buf, -1));
+    Tcl_SetObjResult(interp, Tcl_NewStringObj(buf, TCL_INDEX_NONE));
 
     return TCL_OK;
 
@@ -331,20 +332,19 @@ TpoolCreateObjCmd(
 
 static int
 TpoolPostObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     Tcl_WideInt jobId = 0;
-    int ii, detached = 0, nowait = 0;
-    size_t len;
+    int detached = 0, nowait = 0;
+    Tcl_Size ii, len;
     const char *tpoolName, *script;
     TpoolResult *rPtr;
     ThreadPool *tpoolPtr;
 
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
-    (void)dummy;
 
     /*
      * Syntax: tpool::post ?-detached? ?-nowait? tpoolId script
@@ -369,18 +369,17 @@ TpoolPostObjCmd(
     /*
      * We expect exactly two arguments remaining after options
      */
-    if (objc - ii != 2)
+    if (objc != 2 + ii)
     {
 	goto usage;
     }
 
     tpoolName = Tcl_GetString(objv[ii]);
-    script    = Tcl_GetString(objv[ii+1]);
-    len = objv[ii+1]->length;
+    script    = Tcl_GetStringFromObj(objv[ii+1], &len);
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -458,7 +457,7 @@ TpoolPostObjCmd(
      * Create new job ticket and put it on the list.
      */
 
-    rPtr = (TpoolResult*)ckalloc(sizeof(TpoolResult));
+    rPtr = (TpoolResult *)Tcl_Alloc(sizeof(TpoolResult));
     memset(rPtr, 0, sizeof(TpoolResult));
 
     if (detached == 0) {
@@ -466,7 +465,7 @@ TpoolPostObjCmd(
 	rPtr->jobId = jobId;
     }
 
-    rPtr->script    = strcpy((char *)ckalloc(len+1), script);
+    rPtr->script    = strcpy((char *)Tcl_Alloc(len+1), script);
     rPtr->scriptLen = len;
     rPtr->detached  = detached;
     rPtr->threadId  = Tcl_GetCurrentThread();
@@ -504,12 +503,13 @@ TpoolPostObjCmd(
  */
 static int
 TpoolWaitObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
-    int ii, done, wObjc;
+    int done;
+    Tcl_Size ii, wObjc;
     Tcl_WideInt jobId;
     char *tpoolName;
     Tcl_Obj *listVar = NULL;
@@ -519,7 +519,6 @@ TpoolWaitObjCmd(
     Tcl_HashEntry *hPtr;
 
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
-    (void)dummy;
 
     /*
      * Syntax: tpool::wait tpoolId jobIdList ?listVar?
@@ -539,7 +538,7 @@ TpoolWaitObjCmd(
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -620,19 +619,18 @@ TpoolWaitObjCmd(
  */
 static int
 TpoolCancelObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
-    int ii, wObjc;
+    Tcl_Size ii, wObjc;
     Tcl_WideInt jobId;
     char *tpoolName;
     Tcl_Obj *listVar = NULL;
     Tcl_Obj *doneList, *waitList, **wObjv;
     ThreadPool *tpoolPtr;
     TpoolResult *rPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::cancel tpoolId jobIdList ?listVar?
@@ -652,7 +650,7 @@ TpoolCancelObjCmd(
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -678,10 +676,8 @@ TpoolCancelObjCmd(
 		    tpoolPtr->workTail = rPtr->prevPtr;
 		}
 		SetResult(NULL, rPtr); /* Just to free the result */
-		if (rPtr->script) {
-		    ckfree(rPtr->script);
-		}
-		ckfree((char*)rPtr);
+		Tcl_Free(rPtr->script);
+		Tcl_Free(rPtr);
 		Tcl_ListObjAppendElement(interp, doneList, wObjv[ii]);
 		break;
 	    }
@@ -719,9 +715,9 @@ TpoolCancelObjCmd(
  */
 static int
 TpoolGetObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     int ret;
@@ -731,7 +727,6 @@ TpoolGetObjCmd(
     ThreadPool *tpoolPtr;
     TpoolResult *rPtr;
     Tcl_HashEntry *hPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::get tpoolId jobId ?result?
@@ -756,7 +751,7 @@ TpoolGetObjCmd(
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -770,13 +765,13 @@ TpoolGetObjCmd(
     hPtr = Tcl_FindHashEntry(&tpoolPtr->jobsDone, (void *)(size_t)jobId);
     if (hPtr == NULL) {
 	Tcl_MutexUnlock(&tpoolPtr->mutex);
-	Tcl_AppendResult(interp, "no such job", NULL);
+	Tcl_AppendResult(interp, "no such job", (void *)NULL);
 	return TCL_ERROR;
     }
     rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
     if (rPtr->result == NULL) {
 	Tcl_MutexUnlock(&tpoolPtr->mutex);
-	Tcl_AppendResult(interp, "job not completed", NULL);
+	Tcl_AppendResult(interp, "job not completed", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -785,7 +780,7 @@ TpoolGetObjCmd(
 
     ret = rPtr->retcode;
     SetResult(interp, rPtr);
-    ckfree((char*)rPtr);
+    Tcl_Free(rPtr);
 
     if (resVar) {
 	Tcl_ObjSetVar2(interp, resVar, NULL, Tcl_GetObjResult(interp), 0);
@@ -815,15 +810,14 @@ TpoolGetObjCmd(
 
 static int
 TpoolReserveObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
-    int ret;
+    size_t ret;
     char *tpoolName;
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::preserve tpoolId
@@ -841,13 +835,13 @@ TpoolReserveObjCmd(
     if (tpoolPtr == NULL) {
 	Tcl_MutexUnlock(&listMutex);
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
     ret = TpoolReserve(tpoolPtr);
     Tcl_MutexUnlock(&listMutex);
-    Tcl_SetObjResult(interp, Tcl_NewIntObj(ret));
+    Tcl_SetObjResult(interp, Tcl_NewIntObj((Tcl_WideInt)ret));
 
     return TCL_OK;
 }
@@ -871,15 +865,14 @@ TpoolReserveObjCmd(
 
 static int
 TpoolReleaseObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     size_t ret;
     char *tpoolName;
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::release tpoolId
@@ -897,13 +890,13 @@ TpoolReleaseObjCmd(
     if (tpoolPtr == NULL) {
 	Tcl_MutexUnlock(&listMutex);
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
     ret = TpoolRelease(tpoolPtr);
     Tcl_MutexUnlock(&listMutex);
-    Tcl_SetObjResult(interp, Tcl_NewWideIntObj(ret));
+    Tcl_SetObjResult(interp, Tcl_NewWideIntObj((Tcl_WideInt)ret));
 
     return TCL_OK;
 }
@@ -927,14 +920,13 @@ TpoolReleaseObjCmd(
 
 static int
 TpoolSuspendObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     char *tpoolName;
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::suspend tpoolId
@@ -950,7 +942,7 @@ TpoolSuspendObjCmd(
 
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -978,14 +970,13 @@ TpoolSuspendObjCmd(
 
 static int
 TpoolResumeObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     char *tpoolName;
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     /*
      * Syntax: tpool::resume tpoolId
@@ -1001,7 +992,7 @@ TpoolResumeObjCmd(
 
     if (tpoolPtr == NULL) {
 	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-			 "\"", NULL);
+			 "\"", (void *)NULL);
 	return TCL_ERROR;
     }
 
@@ -1029,14 +1020,13 @@ TpoolResumeObjCmd(
 
 static int
 TpoolNamesObjCmd(
-    ClientData  dummy,         /* Not used. */
+    TCL_UNUSED(void *),        /* Not used. */
     Tcl_Interp *interp,        /* Current interpreter. */
-    int         objc,          /* Number of arguments. */
+    Tcl_Size      objc,          /* Number of arguments. */
     Tcl_Obj    *const objv[]   /* Argument objects. */
 ) {
     ThreadPool *tpoolPtr;
     Tcl_Obj *listObj = Tcl_NewListObj(0, NULL);
-    (void)dummy;
     (void)objc;
     (void)objv;
 
@@ -1044,7 +1034,7 @@ TpoolNamesObjCmd(
     for (tpoolPtr = tpoolList; tpoolPtr; tpoolPtr = tpoolPtr->nextPtr) {
 	char buf[32];
 	snprintf(buf, sizeof(buf), "%s%p", TPOOL_HNDLPREFIX, tpoolPtr);
-	Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(buf,-1));
+	Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(buf, TCL_INDEX_NONE));
     }
     Tcl_MutexUnlock(&listMutex);
     Tcl_SetObjResult(interp, listObj);
@@ -1094,7 +1084,7 @@ CreateWorker(
     Tcl_MutexLock(&startMutex);
     if (Tcl_CreateThread(&id, TpoolWorker, &result,
 			 TCL_THREAD_STACK_DEFAULT, 0) != TCL_OK) {
-	Tcl_SetObjResult(interp, Tcl_NewStringObj("can't create a new thread", -1));
+	Tcl_SetObjResult(interp, Tcl_NewStringObj("can't create a new thread", TCL_INDEX_NONE));
 	Tcl_MutexUnlock(&startMutex);
 	return TCL_ERROR;
     }
@@ -1135,9 +1125,9 @@ CreateWorker(
 
 static Tcl_ThreadCreateType
 TpoolWorker(
-    ClientData clientData
+    void *clientData
 ) {
-    TpoolResult          *rPtr = (TpoolResult*)clientData;
+    TpoolResult          *rPtr = (TpoolResult *)clientData;
     ThreadPool       *tpoolPtr = rPtr->tpoolPtr;
 
     int tout = 0;
@@ -1167,7 +1157,7 @@ TpoolWorker(
 
     if (rPtr->retcode == 1) {
 	errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
-	rPtr->result = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
+	rPtr->result = strcpy((char *)Tcl_Alloc(strlen(errMsg)+1), errMsg);
 	Tcl_ConditionNotify(&tpoolPtr->cond);
 	Tcl_MutexUnlock(&startMutex);
 	goto out;
@@ -1178,11 +1168,11 @@ TpoolWorker(
      */
 
     if (tpoolPtr->initScript) {
-	TpoolEval(interp, tpoolPtr->initScript, -1, rPtr);
+	TpoolEval(interp, tpoolPtr->initScript, TCL_INDEX_NONE, rPtr);
 	if (rPtr->retcode != TCL_OK) {
 	    rPtr->retcode = 1;
 	    errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
-	    rPtr->result  = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
+	    rPtr->result  = strcpy((char *)Tcl_Alloc(strlen(errMsg)+1), errMsg);
 	    Tcl_ConditionNotify(&tpoolPtr->cond);
 	    Tcl_MutexUnlock(&startMutex);
 	    goto out;
@@ -1250,8 +1240,7 @@ TpoolWorker(
 	}
 	Tcl_MutexUnlock(&tpoolPtr->mutex);
 	TpoolEval(interp, rPtr->script, rPtr->scriptLen, rPtr);
-	ckfree(rPtr->script);
-	rPtr->script = NULL;
+	Tcl_Free(rPtr->script);
 	Tcl_MutexLock(&tpoolPtr->mutex);
 	if (!rPtr->detached) {
 	    int isNew;
@@ -1260,7 +1249,7 @@ TpoolWorker(
 			     rPtr);
 	    SignalWaiter(tpoolPtr);
 	} else {
-	    ckfree((char*)rPtr);
+	    Tcl_Free(rPtr);
 	}
     }
 
@@ -1269,7 +1258,7 @@ TpoolWorker(
      */
 
     if (tpoolPtr->exitScript) {
-	TpoolEval(interp, tpoolPtr->exitScript, -1, NULL);
+	TpoolEval(interp, tpoolPtr->exitScript, TCL_INDEX_NONE, NULL);
     }
 
     tpoolPtr->numWorkers--;
@@ -1306,12 +1295,10 @@ TpoolWorker(
  */
 static int
 RunStopEvent(
-    Tcl_Event *dummy,
-    int mask
+    TCL_UNUSED(Tcl_Event *),
+    TCL_UNUSED(int)
 ) {
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
-    (void)dummy;
-    (void)mask;
 
     tsdPtr->stop = 1;
     return 1;
@@ -1529,7 +1516,7 @@ TpoolEval(
     TpoolResult *rPtr
 ) {
     int ret;
-    size_t reslen;
+    Tcl_Size reslen;
     const char *result;
     const char *errorCode, *errorInfo;
 
@@ -1542,22 +1529,21 @@ TpoolEval(
 	errorCode = Tcl_GetVar2(interp, "errorCode", NULL, TCL_GLOBAL_ONLY);
 	errorInfo = Tcl_GetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
 	if (errorCode != NULL) {
-	    rPtr->errorCode = (char *)ckalloc(1 + strlen(errorCode));
+	    rPtr->errorCode = (char *)Tcl_Alloc(1 + strlen(errorCode));
 	    strcpy(rPtr->errorCode, errorCode);
 	}
 	if (errorInfo != NULL) {
-	    rPtr->errorInfo = (char *)ckalloc(1 + strlen(errorInfo));
+	    rPtr->errorInfo = (char *)Tcl_Alloc(1 + strlen(errorInfo));
 	    strcpy(rPtr->errorInfo, errorInfo);
 	}
     }
 
-    result = Tcl_GetString(Tcl_GetObjResult(interp));
-    reslen = Tcl_GetObjResult(interp)->length;
+    result = Tcl_GetStringFromObj(Tcl_GetObjResult(interp), &reslen);
 
     if (reslen == 0) {
 	rPtr->result = threadEmptyResult;
     } else {
-	rPtr->result = strcpy((char *)ckalloc(1 + reslen), result);
+	rPtr->result = strcpy((char *)Tcl_Alloc(1 + reslen), result);
     }
 
     return ret;
@@ -1586,16 +1572,16 @@ SetResult(
     if (rPtr->retcode == TCL_ERROR) {
 	if (rPtr->errorCode) {
 	    if (interp) {
-		Tcl_SetObjErrorCode(interp,Tcl_NewStringObj(rPtr->errorCode,-1));
+		Tcl_SetObjErrorCode(interp,Tcl_NewStringObj(rPtr->errorCode, TCL_INDEX_NONE));
 	    }
-	    ckfree(rPtr->errorCode);
+	    Tcl_Free(rPtr->errorCode);
 	    rPtr->errorCode = NULL;
 	}
 	if (rPtr->errorInfo) {
 	    if (interp) {
-		Tcl_AddErrorInfo(interp, rPtr->errorInfo);
+		Tcl_AppendObjToErrorInfo(interp, Tcl_NewStringObj(rPtr->errorInfo, TCL_INDEX_NONE));
 	    }
-	    ckfree(rPtr->errorInfo);
+	    Tcl_Free(rPtr->errorInfo);
 	    rPtr->errorInfo = NULL;
 	}
     }
@@ -1606,9 +1592,9 @@ SetResult(
 	    }
 	} else {
 	    if (interp) {
-		Tcl_SetObjResult(interp, Tcl_NewStringObj(rPtr->result,-1));
+		Tcl_SetObjResult(interp, Tcl_NewStringObj(rPtr->result, TCL_INDEX_NONE));
 	    }
-	    ckfree(rPtr->result);
+	    Tcl_Free(rPtr->result);
 	    rPtr->result = NULL;
 	}
     }
@@ -1630,7 +1616,7 @@ SetResult(
  *
  *----------------------------------------------------------------------
  */
-static int
+static size_t
 TpoolReserve(
     ThreadPool *tpoolPtr
 ) {
@@ -1696,10 +1682,10 @@ TpoolRelease(
      */
 
     if (tpoolPtr->initScript) {
-	ckfree(tpoolPtr->initScript);
+	Tcl_Free(tpoolPtr->initScript);
     }
     if (tpoolPtr->exitScript) {
-	ckfree(tpoolPtr->exitScript);
+	Tcl_Free(tpoolPtr->exitScript);
     }
 
     /*
@@ -1710,17 +1696,17 @@ TpoolRelease(
     while (hPtr != NULL) {
 	rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
 	if (rPtr->result && rPtr->result != threadEmptyResult) {
-	    ckfree(rPtr->result);
+	    Tcl_Free(rPtr->result);
 	}
 	if (rPtr->retcode == TCL_ERROR) {
 	    if (rPtr->errorInfo) {
-		ckfree(rPtr->errorInfo);
+		Tcl_Free(rPtr->errorInfo);
 	    }
 	    if (rPtr->errorCode) {
-		ckfree(rPtr->errorCode);
+		Tcl_Free(rPtr->errorCode);
 	    }
 	}
-	ckfree((char*)rPtr);
+	Tcl_Free(rPtr);
 	Tcl_DeleteHashEntry(hPtr);
 	hPtr = Tcl_NextHashEntry(&search);
     }
@@ -1730,16 +1716,13 @@ TpoolRelease(
      * Cleanup jobs posted but never completed.
      */
 
-    for (rPtr = tpoolPtr->workHead; rPtr; rPtr = tpoolPtr->workHead) {
-	tpoolPtr->workHead = rPtr->nextPtr;
-	if (rPtr->script) {
-	    ckfree(rPtr->script);
-	}
-	ckfree((char*)rPtr);
+    for (rPtr = tpoolPtr->workHead; rPtr; rPtr = rPtr->nextPtr) {
+	Tcl_Free(rPtr->script);
+	Tcl_Free(rPtr);
     }
     Tcl_MutexFinalize(&tpoolPtr->mutex);
     Tcl_ConditionFinalize(&tpoolPtr->cond);
-    ckfree((char*)tpoolPtr);
+    Tcl_Free(tpoolPtr);
 
     return 0;
 }
@@ -1823,11 +1806,10 @@ SignalWaiter(
 	return;
     }
 
-    evPtr = (Tcl_Event*)ckalloc(sizeof(Tcl_Event));
+    evPtr = (Tcl_Event *)Tcl_Alloc(sizeof(Tcl_Event));
     evPtr->proc = RunStopEvent;
 
-    Tcl_ThreadQueueEvent(waitPtr->threadId,(Tcl_Event*)evPtr,TCL_QUEUE_TAIL);
-    Tcl_ThreadAlert(waitPtr->threadId);
+    Tcl_ThreadQueueEvent(waitPtr->threadId,(Tcl_Event*)evPtr,TCL_QUEUE_TAIL|TCL_QUEUE_ALERT_IF_EMPTY);
 }
 
 /*
@@ -1851,7 +1833,7 @@ InitWaiter ()
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
 
     if (tsdPtr->waitPtr == NULL) {
-	tsdPtr->waitPtr = (TpoolWaiter*)ckalloc(sizeof(TpoolWaiter));
+	tsdPtr->waitPtr = (TpoolWaiter *)Tcl_Alloc(sizeof(TpoolWaiter));
 	tsdPtr->waitPtr->prevPtr  = NULL;
 	tsdPtr->waitPtr->nextPtr  = NULL;
 	tsdPtr->waitPtr->threadId = Tcl_GetCurrentThread();
@@ -1876,11 +1858,11 @@ InitWaiter ()
  */
 static void
 ThrExitHandler(
-    ClientData clientData
+    void *clientData
 ) {
     ThreadSpecificData *tsdPtr = (ThreadSpecificData *)clientData;
 
-    ckfree((char*)tsdPtr->waitPtr);
+    Tcl_Free(tsdPtr->waitPtr);
 }
 
 /*
@@ -1900,10 +1882,9 @@ ThrExitHandler(
  */
 static void
 AppExitHandler(
-    ClientData dummy
+    TCL_UNUSED(void *)
 ) {
     ThreadPool *tpoolPtr;
-    (void)dummy;
 
     Tcl_MutexLock(&listMutex);
     /*
@@ -1952,7 +1933,7 @@ TpoolInit (
     if (initialized == 0) {
 	Tcl_MutexLock(&listMutex);
 	if (initialized == 0) {
-	    Tcl_CreateExitHandler(AppExitHandler, (ClientData)-1);
+	    Tcl_CreateExitHandler(AppExitHandler, (void *)-1);
 	    initialized = 1;
 	}
 	Tcl_MutexUnlock(&listMutex);
