@@ -16,6 +16,7 @@
 #include <ctype.h>
 #include <string.h>
 
+#include "tclThreadInt.h"
 #include "threadSpCmd.h" /* For recursive locks */
 
 /*
@@ -81,17 +82,17 @@
  * persistent storage for shared variable arrays.
  */
 
-typedef ClientData (ps_open_proc)(const char*);
+typedef void *(ps_open_proc)(const char*);
 
-typedef int (ps_get_proc)   (ClientData, const char*, char**, size_t*);
-typedef int (ps_put_proc)   (ClientData, const char*, char*, size_t);
-typedef int (ps_first_proc) (ClientData, char**, char**, size_t*);
-typedef int (ps_next_proc)  (ClientData, char**, char**, size_t*);
-typedef int (ps_delete_proc)(ClientData, const char*);
-typedef int (ps_close_proc) (ClientData);
-typedef void(ps_free_proc)  (ClientData, void*);
+typedef int (ps_get_proc)   (void *, const char*, char**, Tcl_Size*);
+typedef int (ps_put_proc)   (void *, const char*, char*, Tcl_Size);
+typedef int (ps_first_proc) (void *, char**, char**, Tcl_Size*);
+typedef int (ps_next_proc)  (void *, char**, char**, Tcl_Size*);
+typedef int (ps_delete_proc)(void *, const char*);
+typedef int (ps_close_proc) (void *);
+typedef void(ps_free_proc)  (void *, void*);
 
-typedef const char* (ps_geterr_proc)(ClientData);
+typedef const char* (ps_geterr_proc)(void *);
 
 /*
  * This structure maintains a bunch of pointers to functions implementing
@@ -100,7 +101,7 @@ typedef const char* (ps_geterr_proc)(ClientData);
 
 typedef struct PsStore {
     const char *type;          /* Type identifier of the persistent storage */
-    ClientData psHandle;       /* Handle to the opened storage */
+    void *psHandle;            /* Handle to the opened storage */
     ps_open_proc   *psOpen;    /* Function to open the persistent key store */
     ps_get_proc    *psGet;     /* Function to retrieve value bound to key */
     ps_put_proc    *psPut;     /* Function to store user key and value */
@@ -149,7 +150,7 @@ typedef struct Container {
     Tcl_HashEntry *entryPtr;   /* Entry in array table. */
     Tcl_HashEntry *handlePtr;  /* Entry in handles table */
     Tcl_Obj *tclObj;           /* Tcl object to hold shared values */
-    int epoch;                 /* Track object changes */
+    Tcl_Size epoch;            /* Track object changes */
     char *chunkAddr;           /* Address of one chunk of object containers */
     struct Container *nextPtr; /* Next object container in the free list */
     int aolSpecial;
@@ -163,7 +164,7 @@ typedef struct SvCmdInfo {
     char *name;                 /* The short name of the command */
     char *cmdName;              /* Real (rewritten) name of the command */
     char *cmdName2;             /* Real AOL (rewritten) name of the command */
-    Tcl_ObjCmdProc *objProcPtr; /* The object-based command procedure */
+    Tcl_ObjCmdProc2 *objProcPtr; /* The object-based command procedure */
     Tcl_CmdDeleteProc *delProcPtr; /* Pointer to command delete function */
     struct SvCmdInfo *nextPtr;  /* Next in chain of registered commands */
     int aolSpecial;
@@ -191,7 +192,7 @@ typedef struct RegType {
  */
 
 MODULE_SCOPE void
-Sv_RegisterCommand(const char*,Tcl_ObjCmdProc*,Tcl_CmdDeleteProc*, int);
+Sv_RegisterCommand(const char*,Tcl_ObjCmdProc2*,Tcl_CmdDeleteProc*, int);
 
 MODULE_SCOPE void
 Sv_RegisterObjType(const Tcl_ObjType*, Tcl_DupInternalRepProc*);
@@ -200,7 +201,7 @@ MODULE_SCOPE void
 Sv_RegisterPsStore(const PsStore*);
 
 MODULE_SCOPE int
-Sv_GetContainer(Tcl_Interp*,int,Tcl_Obj*const objv[],Container**,int*,int);
+Sv_GetContainer(Tcl_Interp*,Tcl_Size,Tcl_Obj*const objv[],Container**,Tcl_Size*,int);
 
 MODULE_SCOPE int
 Sv_PutContainer(Tcl_Interp*, Container*, int);
